/*
 * Copyright (c) 2011 Imre Fazekas.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the Brillien nor the names of its
 * terms and concepts may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.services.websocket;

import com.vii.brillien.core.component.websocket.BrillienWebSocketApplication;
import com.vii.brillien.core.management.BrillienServices;
import com.vii.brillien.ignition.BrillienContext;
import com.vii.brillien.ignition.transport.BrillienMediator;
import com.vii.brillien.ignition.transport.LoaderComplyer;
import com.vii.brillien.kernel.BrillienException;

public abstract class BrillienMediatorWebSocketApplication extends BrillienWebSocketApplication {

    protected String                    mediatorUsername, mediatorPassword;
    protected BrillienMediator          mediator;

    {
        mediatorUsername = "dispatcher" + this.getClass().getSimpleName();
        mediatorPassword = "dispatcher";
    }

    public String getMediatorUsername() {
        return mediatorUsername;
    }

    public void setMediatorUsername(String mediatorUsername) {
        this.mediatorUsername = mediatorUsername;
    }

    public String getMediatorPassword() {
        return mediatorPassword;
    }

    public void setMediatorPassword(String mediatorPassword) {
        this.mediatorPassword = mediatorPassword;
    }

    public BrillienMediator getMediator() throws BrillienException{
        return mediator;
    }

    @Override
    public void initWebSocketApplication() throws BrillienException{
        if( mediator == null ){
            mediator = BrillienContext.newMediator(mediatorUsername, mediatorPassword, new LoaderComplyer() {
                @Override
                public ClassLoader getLoader(String reference) {
                    try {
                        return BrillienServices.getPresenceManagerByName(
                                BrillienServices.liaison, reference).getClassLoader();
                    } catch (BrillienException e) {
                        e.printStackTrace();
                        return this.getClass().getClassLoader();
                    }
                }
            });
            mediator.connect();
        }
    }

}
