/*
 * Copyright (c) 2011 Imre Fazekas.
 *  All rights reserved.
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice, this
 *  list of conditions and the following disclaimer.
 *
 *  Redistributions in binary form must reproduce the above copyright notice,
 *  this list of conditions and the following disclaimer in the documentation
 *  and/or other materials provided with the distribution.
 *  Neither the name of the Brillien nor the names of its
 *  terms and concepts may be used to endorse or promote products derived from this
 *  software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.services.websocket.applications;

import com.vii.brillien.services.websocket.BrillienMediatorWebSocketApplication;
import org.glassfish.grizzly.websockets.DataFrame;
import org.glassfish.grizzly.websockets.WebSocket;
import org.glassfish.grizzly.websockets.WebSocketAdapter;

public class DelegatorWebSocketApplication extends BrillienMediatorWebSocketApplication {

    private static DelegatorWebSocketApplication    webSocketApplicationInstance;
    protected WebSocketAdapter                      webSocketAdapter;

    static {
        init();
    }

    private static void init(){
        if( webSocketApplicationInstance == null )
            webSocketApplicationInstance = new DelegatorWebSocketApplication();
    }

    public static DelegatorWebSocketApplication getWebSocketApplicationInstance() {
        init();

        return webSocketApplicationInstance;
    }

    public WebSocketAdapter getWebSocketAdapter() {
        return webSocketAdapter;
    }

    public void setWebSocketAdapter(WebSocketAdapter webSocketAdapter) {
        this.webSocketAdapter = webSocketAdapter;
    }

    @Override
    public void onClose(WebSocket socket, DataFrame frame) {
        if( webSocketAdapter != null )
            webSocketAdapter.onClose(socket, frame);
    }

    @Override
    public void onConnect(WebSocket socket) {
        if( webSocketAdapter != null )
            webSocketAdapter.onConnect(socket);
    }

    @Override
    public void onMessage(WebSocket socket, String text) {
        if( webSocketAdapter != null )
            webSocketAdapter.onMessage(socket, text);
    }

    @Override
    public void onMessage(WebSocket socket, byte[] bytes) {
        if( webSocketAdapter != null )
            webSocketAdapter.onMessage(socket, bytes);
    }

    @Override
    public void onPing(WebSocket socket, byte[] bytes) {
        if( webSocketAdapter != null )
            webSocketAdapter.onPing(socket, bytes);
    }

    @Override
    public void onPong(WebSocket socket, byte[] bytes) {
        if( webSocketAdapter != null )
            webSocketAdapter.onPong(socket, bytes);
    }

    @Override
    public void onFragment(WebSocket socket, String fragment, boolean last) {
        if( webSocketAdapter != null )
            webSocketAdapter.onFragment(socket, fragment, last);
    }

    @Override
    public void onFragment(WebSocket socket, byte[] fragment, boolean last) {
        if( webSocketAdapter != null )
            webSocketAdapter.onFragment(socket, fragment, last);
    }

}
